#
# spec file for package b3sum
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           b3sum
Version:        1.5.4
Release:        1.1
Summary:        A multithreaded rust implementation of BLAKE3
License:        Apache-2.0 OR CC0-1.0
URL:            https://github.com/BLAKE3-team/BLAKE3
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging

%description
The official Rust implementation of the BLAKE3 cryptographic hash
function. It uses multithreading by default, making it an order of
magnitude faster than e.g. sha256sum on typical desktop hardware.

%prep
%autosetup -a1 -n %{name}-%{version}/b3sum
mv ../LICENSE_* .

%build
%{cargo_build}

%check
%{cargo_test}

%install
%{cargo_install}

%files
%license LICENSE_A2 LICENSE_A2LLVM LICENSE_CC0

%{_bindir}/%{name}

%changelog
* Mon Aug 19 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.5.4:
  * Initial implementation of SIMD acceleration for the XOF (i.e.
    blake3::Hasher::finalize_xof). This brings long output
    performance into line with long input performance. Currently
    AVX-512-only and Unix-only.
  * The "zeroize" feature no longer depends on proc-macros and syn.
* Thu Jul 18 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.5.3:
  * Revert the serialization change. It was intended to be
    backwards compatible, but that didn't hold for
    non-self-describing serialization formats like bincode.
* Fri Jul 12 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.5.2:
  * build.rs sets cc::Build::emit_rerun_if_env_changed(false) to
    prevent some unnecessary rebuilds
  * Serializing a Hash produces a bytestring instead of an array in
    formats that support bytestrings (like CBOR). Deserialization
    is backwards-compatible with the array format
  * Cleanup and edge case fixes in the C and CMake builds.
* Mon Apr 22 2024 Joshua Smith <smolsheep@opensuse.org>
- Package changes:
  * Swap from obsolete tar_scm to obs_scm
  * Remove obsolete cargo_audit (now part of cargo_vendor)
  * Enable tests
- Update to version 1.5.1:
  * The Rust crate is now compatible with Miri.
  * ~1%% performance improvement on Arm NEON
  * Various fixes and improvements in the CMake build.
  * The MSRV of b3sum is now 1.74.1. (The MSRV of the library crate
    is unchanged, 1.66.1.)
* Sun Dec 31 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 1.5.0:
  * The Rust crate's Hasher type has gained new helper methods
    for common forms of IO: update_reader, update_mmap, and
    update_mmap_rayon. The latter matches the default behavior
    of b3sum. The mmap methods are gated by the new "mmap" Cargo
    feature.
  * Most of the Rust crate's public types now implement the Zeroize
    trait. This is gated by the new "zeroize" Cargo feature.
  * The Rust crate's Hash types now implements the serde Serialize
    and Deserialize traits. This is gated by the new "serde" Cargo
    feature.
  * NEON support is now disabled by default on big-endian AArch64.
    Previously this was a build error if the caller didn't
    explicitly disable it.
* Fri Aug  4 2023 Joshua Smith <jsmithfpv@gmail.com>
- Initial package of blake3/b3sum 1.4.1 for openSUSE
